#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Script Name       : mutagen.py
# Author            : mutsx
# Created           : Mon, 26 Oct 2015
# Last Modified     : Fri, 06 Nov 2015
# License           : MIT


from mutagen.id3 import ID3, TIT2, TPE1, TPE2, ID3NoHeaderError
from mutagen.flac import FLAC, FLACNoHeaderError
from mutagen.oggvorbis import OggVorbis, OggVorbisHeaderError


class Tags:

    def add(self, file, artist, title, extension, clear):
        '''
        Add ID3 tags to a file

        :param file: The already-title-cased file in its new destination
        :param artist: The artist to be set in the ID3 tag
        :param title: The title to be set in the ID3 tag
        :param extension: The extension of the file
        '''
        try:
            if extension == 'mp3':
                audio = ID3(file)
                if clear: audio.clear()
                audio.add(TIT2(encoding=3, text=title))
                audio.add(TPE1(encoding=3, text=artist))
                audio.add(TPE2(encoding=3, text=artist))
                audio.save()
                audio.save(v1=2, v2_version=3)
            elif extension == 'flac':
                audio = FLAC(file)
                if clear: audio.clear()
                audio['TITLE'] = title
                audio['ARTIST'] = artist
                audio.save()
            elif extension == 'ogg':
                audio = OggVorbis(file)
                if clear: audio.clear()
                audio['title'] = artist
                audio['artist'] = artist
                audio['ALBUMARTIST'] = artist
                audio.save()
        except (OggVorbisHeaderError, FLACNoHeaderError, ID3NoHeaderError):
            print('\033[0;31m[ ERROR ]\033[0m {} has no headers. Is this a legit {}-file?'.format(file.replace('!mubu/', ''), extension))

tags = Tags()
